@@ -2,7 +2,6 @@ use camino::Utf8PathBuf;
 
 use crate::{
     config::{Cli, Commands, Opts},
-    ext::PathBufExt,
     run,
 };
 
@@ -19,7 +18,7 @@ async fn workspace_build() {
     run(cli).await.unwrap();
 
     // when running the current working directory is changed to the manifest path.
-    let site_dir = Utf8PathBuf::from("target/site");
+    // let site_dir = Utf8PathBuf::from("target/site");
 
     //insta::assert_snapshot!(site_dir.ls_ascii(0).unwrap_or_default());
 }
